@@ -4,7 +4,4 @@ from jsp_shaving1990 import iterated_full_shaving
 
 def has_schedule(job: Job, UB: int) -> bool:
     result_list, _, _ = iterated_full_shaving(job.attrtolist('r'), job.attrtolist('p'), job.attrtolist('q'), UB)
-    if result_list:
-        return True
-    else:
-        return False
+    return True if result_list else False
